Modules
Structs
- Configure
Client - The client is running in the configure client which would like to configure the nodo app
- Configure
Server - The server is running in the nodo runtime and serves configure requests
- Datarate
Estimation - Executor
- Inspector
Client - The client is running in the report viewer and receives reports
- Inspector
Codelet Report - Inspector
Report - Inspector
Server - The server is running in the nodo runtime and publishes reports
- Rendered
Status - Runtime
- A runtime is needed to schedule codelets
- Schedule
Executor - A schedule of codelets to be executed
- State
Machine - State machine which oversees correct codelet state transitions
- Worker
- Worker
State
Enums
- Configure
Reply - Configure
Request - State
- Possible states of codelets
- Transition
Error - Worker
Reply - Worker
Request
Functions
- accurate_
sleep - Sleeps for a certain duration with high accuracy potentially using a spin loop
- accurate_
sleep_ until - Sleeps up to a time instant with high accuracy potentially using a spin loop
- statistics_
pretty_ print