pub struct WebhookAttemptCreated {
pub meta: Option<AttemptMeta>,
pub attempt_num: u32,
pub attempt_limit: u32,
pub webhook: Option<Webhook>,
}Fields
meta: Option<AttemptMeta>attempt_num: u32Shows how many attempts happened on the same run.
attempt_limit: u32webhook: Option<Webhook>Trait Implementations
Sourceimpl Clone for WebhookAttemptCreated
impl Clone for WebhookAttemptCreated
Sourcefn clone(&self) -> WebhookAttemptCreated
fn clone(&self) -> WebhookAttemptCreated
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebhookAttemptCreated
impl Debug for WebhookAttemptCreated
Sourceimpl Default for WebhookAttemptCreated
impl Default for WebhookAttemptCreated
impl<'de> Deserialize<'de> for WebhookAttemptCreated
impl<'de> Deserialize<'de> for WebhookAttemptCreated
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for WebhookAttemptCreated
impl Message for WebhookAttemptCreated
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WebhookAttemptCreated
impl PartialEq for WebhookAttemptCreated
Sourceimpl ProstLazyDefault for WebhookAttemptCreated
impl ProstLazyDefault for WebhookAttemptCreated
fn default_instance() -> &'static Self
impl Serialize for WebhookAttemptCreated
impl Serialize for WebhookAttemptCreated
impl StructuralPartialEq for WebhookAttemptCreated