pub struct WebhookAttemptSucceeded {
pub meta: Option<AttemptMeta>,
pub attempt_num: u32,
pub attempt_limit: u32,
pub webhook: Option<Webhook>,
pub response_details: Option<WebhookAttemptDetails>,
}Fields
meta: Option<AttemptMeta>attempt_num: u32Shows how many attempts happened on the same run.
attempt_limit: u32webhook: Option<Webhook>response_details: Option<WebhookAttemptDetails>Trait Implementations
Sourceimpl Clone for WebhookAttemptSucceeded
impl Clone for WebhookAttemptSucceeded
Sourcefn clone(&self) -> WebhookAttemptSucceeded
fn clone(&self) -> WebhookAttemptSucceeded
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WebhookAttemptSucceeded
impl Debug for WebhookAttemptSucceeded
Sourceimpl Default for WebhookAttemptSucceeded
impl Default for WebhookAttemptSucceeded
impl<'de> Deserialize<'de> for WebhookAttemptSucceeded
impl<'de> Deserialize<'de> for WebhookAttemptSucceeded
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for WebhookAttemptSucceeded
impl Message for WebhookAttemptSucceeded
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WebhookAttemptSucceeded
impl PartialEq for WebhookAttemptSucceeded
Sourceimpl ProstLazyDefault for WebhookAttemptSucceeded
impl ProstLazyDefault for WebhookAttemptSucceeded
fn default_instance() -> &'static Self
impl Serialize for WebhookAttemptSucceeded
impl Serialize for WebhookAttemptSucceeded
impl StructuralPartialEq for WebhookAttemptSucceeded