pub struct Trigger {
pub id: Option<TriggerId>,
pub name: String,
pub description: Option<String>,
pub action: Option<Action>,
pub schedule: Option<Schedule>,
pub status: Option<i32>,
pub created_at: Option<DateTime>,
pub last_ran_at: Option<DateTime>,
pub updated_at: Option<DateTime>,
pub payload: Option<Payload>,
pub estimated_future_runs: Vec<DateTime>,
}Fields
id: Option<TriggerId>output only
name: String/ User supplied identifier, unique per project
description: Option<String>action: Option<Action>schedule: Option<Schedule>status: Option<i32>output only
created_at: Option<DateTime>output only
last_ran_at: Option<DateTime>output only
updated_at: Option<DateTime>output only
payload: Option<Payload>estimated_future_runs: Vec<DateTime>optional string etag = 9; TODO optional Run last_run_details = 3;
Implementations
Sourceimpl Trigger
impl Trigger
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn status(&self) -> TriggerStatus
pub fn status(&self) -> TriggerStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TriggerStatus)
pub fn set_status(&mut self, value: TriggerStatus)
Sets status to the provided enum value.